@@ -5,7 +5,7 @@ import numpy as np
 from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
-from dataquality.loggers.data_logger.base_data_logger import DataSet
+from dataquality.loggers.data_logger.base_data_logger import ITER_CHUNK_SIZE, DataSet
 from dataquality.loggers.logger_config.text_multi_label import (
     text_multi_label_logger_config,
 )
@@ -15,6 +15,8 @@ from dataquality.schemas.split import Split
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.helpers import check_noop
 
+DEFAULT_RANDOM_EMB_DIM = 2
+
 
 @check_noop
 def log_data_samples(
@@ -102,17 +104,18 @@ def log_data_sample(*, text: str, id: int, **kwargs: Any) -> None:
 def log_dataset(
     dataset: DataSet,
     *,
+    batch_size: int = ITER_CHUNK_SIZE,
     text: Union[str, int] = "text",
     id: Union[str, int] = "id",
     split: Optional[Split] = None,
     meta: Optional[List[Union[str, int]]] = None,
     **kwargs: Any,
 ) -> None:
-    """Log an iterable or other dataset to disk.
+    """Log an iterable or other dataset to disk. Useful for logging memory mapped files
 
-    Dataset provided must be an either a pandas or vaex dataframe, or an iterable that
-    can be traversed row by row, and for each row, the fields can be indexed into
-    either via string keys or int indexes.
+    Dataset provided must be an iterable that can be traversed row by row, and for each
+    row, the fields can be indexed into either via string keys or int indexes. Pandas
+    and Vaex dataframes are also allowed, as well as HuggingFace Datasets
 
     valid examples:
         d = [
@@ -140,7 +143,7 @@ def log_dataset(
         ]
         dq.log_dataset(d, text=0, id=2, label=1)
 
-    invalid example:
+    Invalid example:
         d = {
             "my_text": ["sample1", "sample2", "sample3"],
             "my_labels": ["A", "A", "B"],
@@ -156,6 +159,10 @@ def log_dataset(
 
     Keyword arguments are specific to the task type. See dq.docs() for details
 
+    :param dataset: The iterable or dataframe to log
+    :batch_size: The number of data samples to log at a time. Useful when logging a
+    memory mapped dataset. A larger batch_size will result in faster logging at the
+    expense of more memory usage. Default 100,000
     :param text: str | int The column, key, or int index for text data. Default "text"
     :param id: str | int The column, key, or int index for id data. Default "id"
     :param split: Optional[str] the split for this data. Can also be set via
@@ -170,19 +177,28 @@ def log_dataset(
         [config.task_type, config.current_project_id, config.current_run_id]
     ), "You must call dataquality.init before logging data"
     data_logger = get_data_logger()
-    data_logger.log_dataset(dataset, text=text, id=id, split=split, meta=meta, **kwargs)
+    data_logger.log_dataset(
+        dataset,
+        batch_size=batch_size,
+        text=text,
+        id=id,
+        split=split,
+        meta=meta,
+        **kwargs,
+    )
 
 
 @check_noop
 def log_model_outputs(
     *,
-    embs: Union[List, np.ndarray],
+    embs: Optional[Union[List, np.ndarray]],
     ids: Union[List, np.ndarray],
     split: Optional[Split] = None,
     epoch: Optional[int] = None,
     logits: Union[List, np.ndarray] = None,
     probs: Union[List, np.ndarray] = None,
     inference_name: str = None,
+    exclude_embs: bool = False,
 ) -> None:
     """Logs model outputs for model during training/test/validation.
 
@@ -194,6 +210,8 @@ def log_model_outputs(
     :param probs: Deprecated, use logits. If passed in, a softmax will NOT be applied
     :param inference_name: Inference name indicator for this inference split.
         If logging for an inference split, this is required.
+    :param exclude_embs: Optional flag to exclude embeddings from logging. If True and
+        embs is set to None, this will generate random embs for each sample.
 
     The expected argument shapes come from the task_type being used
     See dq.docs() for more task specific details on parameter shape
@@ -204,6 +222,11 @@ def log_model_outputs(
     assert (probs is not None) or (
         logits is not None
     ), "You must provide either logits or probs"
+    assert (embs is None and exclude_embs) or (
+        embs is not None and not exclude_embs
+    ), "embs can be None if and only if exclude_embs is True"
+    if embs is None and exclude_embs:
+        embs = np.random.rand(len(ids), DEFAULT_RANDOM_EMB_DIM)
     model_logger = get_model_logger()(
         embs=embs,
         ids=ids,
