@@ -16,6 +16,7 @@ from dataquality.loggers.logger_config.base_logger_config import (
 from dataquality.schemas.split import Split, conform_split
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.dq_logger import upload_dq_log_file
+from dataquality.utils.tf import TF_AVAILABLE, is_tf_2
 
 try:
     from torch import Tensor
@@ -24,13 +25,9 @@ try:
 except ImportError:
     TORCH_AVAILABLE = False
 
-try:
+if TF_AVAILABLE:
     import tensorflow as tf
 
-    TF_AVAILABLE = True
-except ImportError:
-    TF_AVAILABLE = False
-
 try:
     import datasets
 
@@ -147,7 +144,10 @@ class BaseGalileoLogger:
                 arr = arr.detach().cpu().numpy()
         if TF_AVAILABLE:
             if isinstance(arr, tf.Tensor):
-                arr = arr.cpu().numpy()
+                if is_tf_2():
+                    arr = arr.cpu().numpy()
+                else:  # Just for TF1.x
+                    arr = arr.numpy()
         if isinstance(arr, np.ndarray):
             if attr == "Embedding":
                 assert (
