@@ -1,4 +1,5 @@
-from typing import List, Optional
+from collections import defaultdict
+from typing import DefaultDict, List, Optional, Set
 
 import numpy as np
 from pydantic import validator
@@ -9,6 +10,7 @@ from dataquality.loggers.logger_config.base_logger_config import BaseLoggerConfi
 class TextMultiLabelLoggerConfig(BaseLoggerConfig):
     labels: Optional[List[List[str]]] = None
     observed_num_labels: Optional[List[int]] = None
+    observed_labels: DefaultDict[int, Set] = defaultdict(set)
     tasks: Optional[List[str]] = None
     observed_num_tasks: int = 0
     binary: bool = False  # For binary multi label
